unit Main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls;

type
  TForm1 = class(TForm)
    Memo1: TMemo;
    Edit1: TEdit;
    btnTest: TButton;
    btnRNDText: TButton;
    Edit2: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    btnEncode: TButton;
    btnDecode: TButton;
    ComboBox1: TComboBox;
    procedure btnTestClick(Sender: TObject);
    procedure btnRNDTextClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure btnEncodeClick(Sender: TObject);
    procedure btnDecodeClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

uses SZCodeBaseX, Math;

{$R *.dfm}

function SZEncodeBase2(const S: string): string;
{
 Example for binary Encoding
}
const
  Codes = '01';
  BITS = 1;
begin
  Result:=SZEncodeBaseX(S, Codes, BITS)
end;

function SZDecodeBase2(const S: string): string;
{
 Example for binary Decoding
}
const
  Codes = '01';
  BITS = 1;
begin
  Result:=SZDecodeBaseX(S, Codes, BITS)
end;

procedure TForm1.btnTestClick(Sender: TObject);
var
  s,e,d: string;

  procedure PrintNote(const s, e, d: string);
  begin
    with Memo1.Lines do
    begin
      Add(s);
      Add('Encode: ' + e);
      Add('Decode: ' + d);
      Add('');
    end
  end;

begin
  Memo1.Clear;

  s:=Edit1.Text;

  with Memo1.Lines do
  begin
    Add('Text for testing: ' + s);
    Add('');

    e:=SZEncodeBase16(s); d:=SZDecodeBase16(e);
    PrintNote('Base16',e,d);

    e:=SZEncodeBase32(s); d:=SZDecodeBase32(e);
    PrintNote('Base32 - RFC 3548 incompatibility - no padding keys',e,d);

    e:=SZFullEncodeBase32(s); d:=SZDecodeBase32(e);
    PrintNote('Base32 - RFC 3548 full compatibility',e,d);

    e:=SZEncodeBase64(s); d:=SZDecodeBase64(e);
    PrintNote('Base64 - RFC 3548 incompatibility - no padding keys',e,d);

    e:=SZFullEncodeBase64(s); d:=SZDecodeBase64(e);
    PrintNote('Base64 - RFC 3548 full compatibility',e,d);

    e:=SZEncodeBase64URL(s); d:=SZDecodeBase64URL(e);
    PrintNote('Base64URL - RFC 3548 incompatibility - no padding keys',e,d);

    e:=SZFullEncodeBase64URL(s); d:=SZDecodeBase64URL(e);
    PrintNote('Base64URL - RFC 3548 full compatibility',e,d);

    e:=SZEncodeBase2(s); d:=SZDecodeBase2(e);
    PrintNote('Base2 - Example how to create your own base Encode/Decode functions',e,d);

   end;
end;

procedure TForm1.btnRNDTextClick(Sender: TObject);
var
  i,len: integer;
begin

  Edit1.Text:='';

  Randomize;
  len := 40;

  i:=0;
  repeat
    inc(i);
    Edit1.Text := Edit1.Text + chr(Random(256));
  until i>=len;

  btnTest.Click;

end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  btnTest.Click
end;

procedure TForm1.btnEncodeClick(Sender: TObject);
var
  e,d: string;
begin
  d:=Edit1.Text;
  case ComboBox1.ItemIndex of
    0: e:=SZEncodeBase16(d);
    1: e:=SZEncodeBase32(d);
    2: e:=SZEncodeBase64(d);
    3: e:=SZEncodeBase64URL(d);
    4: e:=SZEncodeBase2(d);
    5: e:=SZFullEncodeBase32(d);
    6: e:=SZFullEncodeBase64(d);
    7: e:=SZFullEncodeBase64URL(d);
  end;
  Edit2.Text:=e;
end;

procedure TForm1.btnDecodeClick(Sender: TObject);
var
  e,d: string;
begin

  e:=Edit2.Text;
  case ComboBox1.ItemIndex of
    0: d:=SZDecodeBase16(e);
    1: d:=SZDecodeBase32(e);
    2: d:=SZDecodeBase64(e);
    3: d:=SZDecodeBase64URL(e);
    4: d:=SZDecodeBase2(e);
    5: d:=SZDecodeBase32(e);
    6: d:=SZDecodeBase64(e);
    7: d:=SZDecodeBase64URL(e);
  end;
  Edit1.Text:=d;

end;

end.
